#' @method AIC ml
#' @export
AIC.ml<-function(object,...)
{
  return(object$AIC)
}
